Stable identity key for virtual items.
Supports numeric and string-based keys for custom key extractors that produce stable identities across item reordering.
Enums
- Virtual
Key - Stable identity key for a virtual item.
Stable identity key for virtual items.
Supports numeric and string-based keys for custom key extractors that produce stable identities across item reordering.